@@ -14,9 +14,9 @@ Interface specifications below.
 
     class name: BaseObject
 
-Hyper-parameter inspection and setter methods:
-    inspect hyper-parameters     - get_params()
-    setting hyper-parameters     - set_params(**params)
+Hyper-parameter inspection and setter methods
+    inspect hyper-parameters      - get_params()
+    setting hyper-parameters      - set_params(**params)
 
 Tag inspection and setter methods
     inspect tags (all)            - get_tags()
@@ -26,6 +26,9 @@ Tag inspection and setter methods
     setting dynamic tags          - set_tag(**tag_dict: dict)
     set/clone dynamic tags        - clone_tags(estimator, tag_names=None)
 
+Re-initialize object to post-init state with same hyper-parameters
+    reset estimator to post-init  - reset()
+
 Testing with default parameters methods
     getting default parameters (all sets)         - get_test_params()
     get one test instance with default parameters - create_test_instance()
@@ -69,6 +72,36 @@ class BaseObject(_BaseEstimator):
         self._tags_dynamic = dict()
         super(BaseObject, self).__init__()
 
+    def reset(self):
+        """Reset the object to a clean post-init state.
+
+        Equivalent to sklearn.clone but overwrites self.
+        After self.reset() call, self is equal in value to
+        `type(self)(**self.get_params(deep=False))`
+
+        Detail behaviour:
+        removes any object attributes, except:
+            hyper-parameters = arguments of __init__
+            object attributes containing double-underscores, i.e., the string "__"
+        runs __init__ with current values of hyper-parameters (result of get_params)
+
+        Not affected by the reset are:
+        object attributes containing double-underscores
+        class and object methods, class attributes
+        """
+        # retrieve parameters to copy them later
+        params = self.get_params(deep=False)
+
+        # delete all object attributes in self
+        attrs = [attr for attr in dir(self) if "__" not in attr]
+        cls_attrs = [attr for attr in dir(type(self))]
+        self_attrs = set(attrs).difference(cls_attrs)
+        for attr in self_attrs:
+            delattr(self, attr)
+
+        # run init with a copy of parameters self had at the start
+        self.__init__(**params)
+
     @classmethod
     def get_class_tags(cls):
         """Get class tags from estimator class and all its parent classes.
