@@ -76,6 +76,7 @@ class ClassifierPipeline(BaseClassifier, _HeterogenousMetaEstimator):
     >>> from sktime.transformations.panel.pca import PCATransformer
     >>> from sktime.classification.interval_based import TimeSeriesForestClassifier
     >>> from sktime.datasets import load_unit_test
+    >>> from sktime.classification.compose import ClassifierPipeline
     >>> X_train, y_train = load_unit_test(split="train")
     >>> X_test, y_test = load_unit_test(split="test")
     >>> pipeline = ClassifierPipeline(
@@ -274,7 +275,7 @@ class ClassifierPipeline(BaseClassifier, _HeterogenousMetaEstimator):
 
         Parameters
         ----------
-        deep : boolean, optional
+        deep : boolean, optional, default=True
             If True, will return the parameters for this estimator and
             contained sub-objects that are estimators.
 
