@@ -11,22 +11,20 @@ import numpy as np
 import pandas as pd
 from joblib import Parallel, delayed
 from scipy import stats
-from sklearn.preprocessing import LabelEncoder, normalize
+from sklearn.preprocessing import normalize
 from sklearn.utils import check_random_state
 
 from sktime.classification.base import BaseClassifier
 from sktime.datatypes._panel._convert import from_nested_to_2d_array
-from sktime.distances.elastic_cython import (
+from sktime.distances import (
     dtw_distance,
     erp_distance,
     lcss_distance,
     msm_distance,
-    twe_distance,
     wdtw_distance,
 )
 from sktime.transformations.base import _PanelToPanelTransformer
 from sktime.transformations.panel.summarize import DerivativeSlopeTransformer
-from sktime.utils.validation.panel import check_X, check_X_y
 
 # todo unit tests / sort out current unit tests
 # todo logging package rather than print to screen
@@ -45,7 +43,7 @@ class _CachedTransformer(_PanelToPanelTransformer):
 
     Parameters
     ----------
-    transformer : the transformer to transform uncached data
+    transformer: the transformer to transform uncached data
 
     Attributes
     ----------
@@ -143,28 +141,19 @@ def distance_predefined_params(distance_measure, **params):
     return distance
 
 
-def cython_wrapper(distance_measure):
-    """Wrap a distance measure in cython conversion.
+def numba_wrapper(distance_measure):
+    """Wrap a numba distance measure with numpy conversion.
 
-     Converts to 1 column per dimension format.
+     Converts to 1 column per dimension format. Really would be better if the whole
+     thing worked directly with numpy arrays.
     :param distance_measure: distance measure to wrap
-    :returns: a distance measure which automatically formats data for cython
+    :returns: a distance measure which automatically formats data for numba
     distance measures
     """
 
     def distance(instance_a, instance_b, **params):
-        # find distance
-        instance_a = from_nested_to_2d_array(
-            instance_a, return_numpy=True
-        )  # todo use specific
-        # dimension rather than whole
-        # thing?
-        instance_b = from_nested_to_2d_array(
-            instance_b, return_numpy=True
-        )  # todo use specific
-        # dimension rather than whole thing?
-        instance_a = np.transpose(instance_a)
-        instance_b = np.transpose(instance_b)
+        instance_a = from_nested_to_2d_array(instance_a, return_numpy=True)
+        instance_b = from_nested_to_2d_array(instance_b, return_numpy=True)
         return distance_measure(instance_a, instance_b, **params)
 
     return distance
@@ -278,7 +267,9 @@ def get_one_exemplar_per_class_proximity(proximity):
     result : function
         function choosing one exemplar per class
     """
-    return get_one_exemplar_per_class(proximity.X, proximity.y, proximity.random_state)
+    return get_one_exemplar_per_class(
+        proximity.X, proximity.y, proximity._random_object
+    )
 
 
 def get_one_exemplar_per_class(X, y, random_state):
@@ -329,8 +320,8 @@ def dtw_distance_measure_getter(X):
     :returns: distance measure and parameter range dictionary
     """
     return {
-        "distance_measure": [cython_wrapper(dtw_distance)],
-        "w": stats.uniform(0, 0.25),
+        "distance_measure": [numba_wrapper(dtw_distance)],
+        "window": stats.uniform(0, 0.25),
     }
 
 
@@ -342,7 +333,7 @@ def msm_distance_measure_getter(X):
     """
     n_dimensions = 1  # todo use other dimensions
     return {
-        "distance_measure": [cython_wrapper(msm_distance)],
+        "distance_measure": [numba_wrapper(msm_distance)],
         "dim_to_use": stats.randint(low=0, high=n_dimensions),
         "c": [
             0.01,
@@ -461,7 +452,7 @@ def erp_distance_measure_getter(X):
     max_raw_warping_window = np.floor((instance_length + 1) / 4)
     n_dimensions = 1  # todo use other dimensions
     return {
-        "distance_measure": [cython_wrapper(erp_distance)],
+        "distance_measure": [numba_wrapper(erp_distance)],
         "dim_to_use": stats.randint(low=0, high=n_dimensions),
         "g": stats.uniform(0.2 * stdp, 0.8 * stdp - 0.2 * stdp),
         "band_size": stats.randint(low=0, high=max_raw_warping_window + 1)
@@ -481,7 +472,7 @@ def lcss_distance_measure_getter(X):
     max_raw_warping_window = np.floor((instance_length + 1) / 4)
     n_dimensions = 1  # todo use other dimensions
     return {
-        "distance_measure": [cython_wrapper(lcss_distance)],
+        "distance_measure": [numba_wrapper(lcss_distance)],
         "dim_to_use": stats.randint(low=0, high=n_dimensions),
         "epsilon": stats.uniform(0.2 * stdp, stdp - 0.2 * stdp),
         # scipy stats randint is exclusive on the max value, hence + 1
@@ -489,28 +480,28 @@ def lcss_distance_measure_getter(X):
     }
 
 
-def twe_distance_measure_getter(X):
-    """Generate the twe distance measure.
-
-    :param X: dataset to derive parameter ranges from
-    :returns: distance measure and parameter range dictionary
-    """
-    return {
-        "distance_measure": [cython_wrapper(twe_distance)],
-        "penalty": [
-            0,
-            0.011111111,
-            0.022222222,
-            0.033333333,
-            0.044444444,
-            0.055555556,
-            0.066666667,
-            0.077777778,
-            0.088888889,
-            0.1,
-        ],
-        "stiffness": [0.00001, 0.0001, 0.0005, 0.001, 0.005, 0.01, 0.05, 0.1, 0.5, 1],
-    }
+# def twe_distance_measure_getter(X):
+#     """Generate the twe distance measure.
+#
+#     :param X: dataset to derive parameter ranges from
+#     :returns: distance measure and parameter range dictionary
+#     """
+#     return {
+#         "distance_measure": [cython_wrapper(twe_distance)],
+#         "penalty": [
+#             0,
+#             0.011111111,
+#             0.022222222,
+#             0.033333333,
+#             0.044444444,
+#             0.055555556,
+#             0.066666667,
+#             0.077777778,
+#             0.088888889,
+#             0.1,
+#         ],
+#         "stiffness": [0.00001, 0.0001, 0.0005, 0.001, 0.005, 0.01, 0.05, 0.1, 0.5, 1],
+#     }
 
 
 def wdtw_distance_measure_getter(X):
@@ -520,7 +511,7 @@ def wdtw_distance_measure_getter(X):
     :returns: distance measure and parameter range dictionary
     """
     return {
-        "distance_measure": [cython_wrapper(wdtw_distance)],
+        "distance_measure": [numba_wrapper(wdtw_distance)],
         "g": stats.uniform(0, 1),
     }
 
@@ -531,7 +522,7 @@ def euclidean_distance_measure_getter(X):
     :param X: dataset to derive parameter ranges from
     :returns: distance measure and parameter range dictionary
     """
-    return {"distance_measure": [cython_wrapper(dtw_distance)], "w": [0]}
+    return {"distance_measure": [numba_wrapper(dtw_distance)], "w": [0]}
 
 
 def setup_wddtw_distance_measure_getter(transformer):
@@ -545,7 +536,7 @@ def setup_wddtw_distance_measure_getter(transformer):
     def getter(X):
         return {
             "distance_measure": [
-                _derivative_distance(cython_wrapper(wdtw_distance), transformer)
+                _derivative_distance(numba_wrapper(wdtw_distance), transformer)
             ],
             "g": stats.uniform(0, 1),
         }
@@ -564,7 +555,7 @@ def setup_ddtw_distance_measure_getter(transformer):
     def getter(X):
         return {
             "distance_measure": [
-                _derivative_distance(cython_wrapper(dtw_distance), transformer)
+                _derivative_distance(numba_wrapper(dtw_distance), transformer)
             ],
             "w": stats.uniform(0, 0.25),
         }
@@ -588,7 +579,7 @@ def setup_all_distance_measure_getter(proximity):
         msm_distance_measure_getter,
         lcss_distance_measure_getter,
         erp_distance_measure_getter,
-        twe_distance_measure_getter,
+        #        twe_distance_measure_getter,
     ]
 
     def pick_rand_distance_measure(proximity):
@@ -598,7 +589,7 @@ def setup_all_distance_measure_getter(proximity):
         ranges and dataset
         :returns: a distance measure with no parameters
         """
-        random_state = proximity.random_state
+        random_state = check_random_state(proximity.random_state)
         X = proximity.X
         distance_measure_getter = random_state.choice(distance_measure_getters)
         distance_measure_perm = distance_measure_getter(X)
@@ -737,7 +728,7 @@ def best_of_n_stumps(n):
             stump.grow()
             stumps.append(stump)
         # pick the best stump based upon gain
-        stump = _max(stumps, proximity.random_state, lambda stump: stump.entropy)
+        stump = _max(stumps, proximity._random_object, lambda stump: stump.entropy)
         return stump
 
     return find_best_stump
@@ -748,32 +739,25 @@ class ProximityStump(BaseClassifier):
 
     Model a decision stump which uses a distance measure to partition data.
 
-    Attributes
+    Parameters
     ----------
-        label_encoder: label encoder to change string labels to numeric indices
-        y_exemplar: class label list of the exemplar instances
-        X_exemplar: dataframe of the exemplar instances
-        X_branches: dataframes for each branch, one per exemplar
-        y_branches: class label list for each branch, one per exemplar
-        classes_: unique list of classes
-        entropy: the gain associated with the split of data
-        random_state: the random state
-        get_exemplars: function to extract exemplars from a dataframe and
-        class value list
-        setup_distance_measure: function to setup the distance measure
-        getters from dataframe and class value list
-        get_distance_measure: distance measure getters
-        distance_measure: distance measures
-        get_gain: function to score the quality of a split
-        verbosity: logging verbosity
-        n_jobs: number of jobs to run in parallel *across threads"
+    random_state: integer, the random state
+    get_exemplars: function
+        extract exemplars from a dataframe and class value list
+    setup_distance_measure: function
+        setup the distance measure getters from dataframe and class value list
+    get_distance_measure: distance measure getters
+    distance_measure: distance measures
+    get_gain: function to score the quality of a split
+    verbosity: logging verbosity
+    n_jobs: number of jobs to run in parallel *across threads"
 
     Examples
     --------
     >>> from sktime.classification.distance_based import ProximityStump
     >>> from sktime.datasets import load_unit_test
-    >>> X_train, y_train = load_unit_test(split="train", return_X_y=True)
-    >>> X_test, y_test = load_unit_test(split="test", return_X_y=True)
+    >>> X_train, y_train = load_unit_test(split="train")
+    >>> X_test, y_test = load_unit_test(split="test")
     >>> clf = ProximityStump()
     >>> clf.fit(X_train, y_train)
     ProximityStump(...)
@@ -782,8 +766,7 @@ class ProximityStump(BaseClassifier):
 
     _tags = {
         "capability:multithreading": True,
-        "coerce-X-to-numpy": False,
-        "coerce-X-to-pandas": True,
+        "X_inner_mtype": "nested_univ",  # input in nested dataframe
     }
 
     __author__ = "George Oastler (linkedin.com/goastler; github.com/goastler)"
@@ -799,20 +782,6 @@ class ProximityStump(BaseClassifier):
         verbosity=0,
         n_jobs=1,
     ):
-        """
-        Construct a proximity stump.
-
-        :param random_state: the random state
-        :param get_exemplars: function to extract exemplars from a dataframe
-        and class value list
-        :param setup_distance_measure: function to setup the distance
-        measure getters from dataframe and class value list
-        :param get_distance_measure: distance measure getters
-        :param distance_measure: distance measures
-        :param get_gain: function to score the quality of a split
-        :param verbosity: logging verbosity
-        :param n_jobs: number of jobs to run in parallel *across threads"
-        """
         self.setup_distance_measure = setup_distance_measure
         self.random_state = random_state
         self.get_distance_measure = get_distance_measure
@@ -830,7 +799,8 @@ class ProximityStump(BaseClassifier):
         self.X = None
         self.y = None
         self.entropy = None
-
+        self._random_object = None
+        self._get_distance_measure = None
         super(ProximityStump, self).__init__()
 
     @staticmethod
@@ -869,7 +839,6 @@ class ProximityStump(BaseClassifier):
         2d numpy array of distances from each instance to each
         exemplar (instance by exemplar)
         """
-        check_X(X)
         if self._threads_to_use > 1:
             parallel = Parallel(self._threads_to_use)
             distances = parallel(
@@ -905,17 +874,14 @@ class ProximityStump(BaseClassifier):
         self : object
         """
         self.X = _positive_dataframe_indices(X)
-        self.random_state = check_random_state(self.random_state)
-        # setup label encoding
-        if self.label_encoder is None:
-            self.label_encoder = LabelEncoder()
-            y = self.label_encoder.fit_transform(y)
+        self._random_object = check_random_state(self.random_state)
         self.y = y
-        self.classes_ = self.label_encoder.classes_
         if self.distance_measure is None:
             if self.get_distance_measure is None:
-                self.get_distance_measure = self.setup_distance_measure(self)
-            self.distance_measure = self.get_distance_measure(self)
+                self._get_distance_measure = self.setup_distance_measure(self)
+            else:
+                self._get_distance_measure = self.get_distance_measure
+            self.distance_measure = self._get_distance_measure(self)
         self.X_exemplar, self.y_exemplar = self.get_exemplars(self)
 
         return self
@@ -932,13 +898,12 @@ class ProximityStump(BaseClassifier):
         1d numpy array of indices, one for each instance,
         reflecting the index of the closest exemplar
         """
-        check_X(X)  # todo make checks optional and propogate from forest downwards
         n_instances = X.shape[0]
         distances = self.distance_to_exemplars(X)
         indices = np.empty(X.shape[0], dtype=int)
         for index in range(n_instances):
             exemplar_distances = distances[index]
-            closest_exemplar_index = _arg_min(exemplar_distances, self.random_state)
+            closest_exemplar_index = _arg_min(exemplar_distances, self._random_object)
             indices[index] = closest_exemplar_index
         return indices
 
@@ -957,7 +922,7 @@ class ProximityStump(BaseClassifier):
         self.entropy = self.get_gain(self.y, self.y_branches)
         return self
 
-    def _predict(self, X):
+    def _predict(self, X) -> np.ndarray:
         """Predicts labels for sequences in X.
 
         Parameters
@@ -981,11 +946,10 @@ class ProximityStump(BaseClassifier):
             distribution = distributions[instance_index]
             prediction = np.argmax(distribution)
             predictions.append(prediction)
-        y = self.label_encoder.inverse_transform(predictions)
 
-        return y
+        return np.array(predictions)
 
-    def _predict_proba(self, X):
+    def _predict_proba(self, X) -> np.ndarray:
         """Find probability estimates for each class for all cases in X.
 
         Parameters
@@ -1011,6 +975,23 @@ class ProximityStump(BaseClassifier):
         normalize(distributions, copy=False, norm="l1")
         return distributions
 
+    @classmethod
+    def get_test_params(cls):
+        """Return testing parameter settings for the estimator.
+
+        Returns
+        -------
+        params : dict or list of dict, default = {}
+            Parameters to create testing instances of the class
+            Each dict are parameters to construct an "interesting" test instance, i.e.,
+            `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
+            `create_test_instance` uses the first (or only) dictionary in `params`
+        """
+        params = {
+            "random_state": 0,
+        }
+        return params
+
 
 class ProximityTree(BaseClassifier):
     """Proximity Tree class.
@@ -1019,26 +1000,37 @@ class ProximityTree(BaseClassifier):
 
     Attributes
     ----------
-        label_encoder: label encoder to change string labels to numeric indices
-        classes_: unique list of classes
-        random_state: the random state
-        get_exemplars: function to extract exemplars from a dataframe and
-        class value list
-        setup_distance_measure: function to setup the distance measure
-        getters from dataframe and class value list
-        get_distance_measure: distance measure getters
-        distance_measure: distance measures
-        get_gain: function to score the quality of a split
+        random_state            : the random state
+        get_exemplars:
+            function to extract exemplars from a dataframe and class value list
+        distance_measure        : distance measures
+        get_distance_measure    : distance measure getters
+        setup_distance_measure  : function
+            setup the distance measure getters from dataframe and class value list
+        get_gain                : function
+            score the quality of a split
         verbosity: logging verbosity
+        is_leaf                 : function
+            decide when to mark a node as a leaf node
         n_jobs: number of jobs to run in parallel *across threads"
         find_stump: function to find the best split of data
         max_depth: max tree depth
         depth: current depth of tree, as each node is a tree itself,
         therefore can have a depth of >=0
-        X: train data
-        y: train data labels
         stump: the stump used to split data at this node
         branches: the partitions of data driven by the stump
+        get_exemplars: get the exemplars from a given dataframe and list of class labels
+        distance_measure: distance measure to use
+        get_distance_measure: method to get the distance measure
+        setup_distance_measure: method to setup the distance measures based upon the
+        dataset given
+        get_gain: method to find the gain of a data split
+        max_depth: maximum depth of the tree
+        verbosity: number reflecting the verbosity of logging
+        n_jobs: number of parallel threads to use while building
+        find_stump: method to find the best split of data / stump at a node
+        n_stump_evaluations: number of stump evaluations to do if
+        find_stump method is None
 
     Examples
     --------
@@ -1046,7 +1038,7 @@ class ProximityTree(BaseClassifier):
     >>> from sktime.datasets import load_unit_test
     >>> X_train, y_train = load_unit_test(split="train", return_X_y=True)
     >>> X_test, y_test = load_unit_test(split="test", return_X_y=True)
-    >>> clf = ProximityTree()
+    >>> clf = ProximityTree(max_depth=2, n_stump_evaluations=1)
     >>> clf.fit(X_train, y_train)
     ProximityTree(...)
     >>> y_pred = clf.predict(X_test)
@@ -1054,14 +1046,11 @@ class ProximityTree(BaseClassifier):
 
     _tags = {
         "capability:multithreading": True,
-        "coerce-X-to-numpy": False,
-        "coerce-X-to-pandas": True,
+        "X_inner_mtype": "nested_univ",
     }
 
     def __init__(
         self,
-        # note: any changes of these params must be reflected in
-        # the fit method for building trees / clones
         random_state=None,
         get_exemplars=get_one_exemplar_per_class_proximity,
         distance_measure=None,
@@ -1075,26 +1064,6 @@ class ProximityTree(BaseClassifier):
         n_stump_evaluations=5,
         find_stump=None,
     ):
-        """Build a Proximity Tree object.
-
-        :param random_state: the random state
-        :param get_exemplars: get the exemplars from a given dataframe and
-        list of class labels
-        :param distance_measure: distance measure to use
-        :param get_distance_measure: method to get the distance measure if
-        no already set
-        :param setup_distance_measure: method to setup the distance measures
-        based upon the dataset given
-        :param get_gain: method to find the gain of a data split
-        :param max_depth: maximum depth of the tree
-        :param is_leaf: function to decide when to mark a node as a leaf node
-        :param verbosity: number reflecting the verbosity of logging
-        :param n_jobs: number of parallel threads to use while building
-        :param find_stump: method to find the best split of data / stump at
-        a node
-        :param n_stump_evaluations: number of stump evaluations to do if
-        find_stump method is None
-        """
         self.verbosity = verbosity
         self.n_stump_evaluations = n_stump_evaluations
         self.find_stump = find_stump
@@ -1115,6 +1084,7 @@ class ProximityTree(BaseClassifier):
         self.branches = None
         self.X = None
         self.y = None
+        self._random_object = None
 
         super(ProximityTree, self).__init__()
 
@@ -1134,15 +1104,10 @@ class ProximityTree(BaseClassifier):
         self : object
         """
         self.X = _positive_dataframe_indices(X)
-        self.random_state = check_random_state(self.random_state)
+        self._random_object = check_random_state(self.random_state)
         if self.find_stump is None:
             self.find_stump = best_of_n_stumps(self.n_stump_evaluations)
-        # setup label encoding
-        if self.label_encoder is None:
-            self.label_encoder = LabelEncoder()
-            y = self.label_encoder.fit_transform(y)
         self.y = y
-        self.classes_ = self.label_encoder.classes_
         if self.distance_measure is None:
             if self.get_distance_measure is None:
                 self.get_distance_measure = self.setup_distance_measure(self)
@@ -1174,7 +1139,7 @@ class ProximityTree(BaseClassifier):
 
         return self
 
-    def _predict(self, X):
+    def _predict(self, X) -> np.ndarray:
         """Predicts labels for sequences in X.
 
         Parameters
@@ -1198,11 +1163,10 @@ class ProximityTree(BaseClassifier):
             distribution = distributions[instance_index]
             prediction = np.argmax(distribution)
             predictions.append(prediction)
-        y = self.label_encoder.inverse_transform(predictions)
 
-        return y
+        return np.array(predictions)
 
-    def _predict_proba(self, X):
+    def _predict_proba(self, X) -> np.ndarray:
         """Find probability estimates for each class for all cases in X.
 
         Parameters
@@ -1222,25 +1186,51 @@ class ProximityTree(BaseClassifier):
         """
         X = _negative_dataframe_indices(X)
         closest_exemplar_indices = self.stump.find_closest_exemplar_indices(X)
-        n_classes = len(self.label_encoder.classes_)
-        distribution = np.zeros((X.shape[0], n_classes))
+        distribution = np.full((X.shape[0], self.n_classes_), 0.0001)
         for index in range(len(self.branches)):
             indices = np.argwhere(closest_exemplar_indices == index)
             if indices.shape[0] > 0:
                 indices = np.ravel(indices)
                 sub_tree = self.branches[index]
                 if sub_tree is None:
-                    sub_distribution = np.zeros((1, n_classes))
+                    sub_distribution = np.full(
+                        (1, self.n_classes_), np.finfo(float).eps
+                    )
                     class_label = self.stump.y_exemplar[index]
-                    sub_distribution[0][class_label] = 1
+                    sub_distribution[0][self._class_dictionary[class_label]] = 1
                 else:
                     sub_X = X.iloc[indices, :]
                     sub_distribution = sub_tree.predict_proba(sub_X)
-                assert sub_distribution.shape[1] == n_classes
+                if sub_distribution.shape[1] != self.n_classes_:
+                    sub_distribution = np.zeros((1, self.n_classes_))
                 np.add.at(distribution, indices, sub_distribution)
         normalize(distribution, copy=False, norm="l1")
         return distribution
 
+    @classmethod
+    def get_test_params(cls, parameter_set="default"):
+        """Return testing parameter settings for the estimator.
+
+        Parameters
+        ----------
+        parameter_set : str, default="default"
+            Name of the set of test parameters to return, for use in tests. If no
+            special parameters are defined for a value, will return `"default"` set.
+            For classifiers, a "default" set of parameters should be provided for
+            general testing, and a "results_comparison" set for comparing against
+            previously recorded results if the general set does not produce suitable
+            probabilities to compare against.
+
+        Returns
+        -------
+        params : dict or list of dict, default={}
+            Parameters to create testing instances of the class.
+            Each dict are parameters to construct an "interesting" test instance, i.e.,
+            `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
+            `create_test_instance` uses the first (or only) dictionary in `params`.
+        """
+        return {"max_depth": 1, "n_stump_evaluations": 1}
+
 
 class ProximityForest(BaseClassifier):
     """Proximity Forest class.
@@ -1249,38 +1239,24 @@ class ProximityForest(BaseClassifier):
 
     Parameters
     ----------
-    random_state: random, default = None
+    random_state        : random, default = None
         seed for reproducibility
-    n_estimators : int, default=100
+    n_estimators        : int, default=100
         The number of trees in the forest.
     distance_measure: default = None
-    get_distance_measure: default=None,
-        distance measure getters
-    get_exemplars: default=get_one_exemplar_per_class_proximity,
-    get_gain: default=gini_gain,
-            function to score the quality of a split
-    verbosity: default=0,
-            logging verbosity
-    max_depth: default=np.math.inf,
-    is_leaf: default=pure,
-    n_jobs: default=int, 1,
+    get_exemplars: default=get_one_exemplar_per_class_proximity
+    get_gain: default=gini_gain
+        function to score the quality of a split
+    verbosity: default=0
+    max_depth: default=np.math.inf
+        maximum depth of the tree
+    is_leaf: default=pure
+        function to decide when to mark a node as a leaf node
+    n_jobs: default=int, 1
         number of jobs to run in parallel *across threads"
-    n_stump_evaluations: int, default=5,
-    find_stump: default=None,
-        function to find the best split of data
-    setup_distance_measure_getter=setup_all_distance_measure_getter,
-    setup_distance_measure_getter: function to setup the distance
-
-    Attributes
-    ----------
-    label_encoder: label encoder to change string labels to numeric indices
-    classes_: unique list of classes
-    get_exemplars: function to extract exemplars from a dataframe and
-           class value list
-    max_depth: max tree depth
-    X: train data
-    y: train data labels
-    trees: list of trees in the forest
+    n_stump_evaluations: int, default=5
+    find_stump: default=None, function to find the best split of data
+    setup_distance_measure_getter=setup_all_distance_measure_getter
 
     Notes
     -----
@@ -1300,16 +1276,16 @@ class ProximityForest(BaseClassifier):
     >>> from sktime.datasets import load_unit_test
     >>> X_train, y_train = load_unit_test(split="train", return_X_y=True)
     >>> X_test, y_test = load_unit_test(split="test", return_X_y=True)
-    >>> clf = ProximityForest(n_estimators=5)
+    >>> clf = ProximityForest(n_estimators=2, max_depth=2, n_stump_evaluations=1)
     >>> clf.fit(X_train, y_train)
     ProximityForest(...)
     >>> y_pred = clf.predict(X_test)
     """
 
     _tags = {
+        "X_inner_mtype": "nested_univ",
         "capability:multithreading": True,
-        "coerce-X-to-numpy": False,
-        "coerce-X-to-pandas": True,
+        "classifier_type": "distance",
     }
 
     def __init__(
@@ -1328,29 +1304,6 @@ class ProximityForest(BaseClassifier):
         find_stump=None,
         setup_distance_measure_getter=setup_all_distance_measure_getter,
     ):
-        """Build a Proximity Forest object.
-
-        Parameters
-        ----------
-        random_state: the random state
-        get_exemplars: get the exemplars from a given dataframe and
-        list of class labels
-        distance_measure: distance measure to use
-        get_distance_measure: method to get the distance measure if
-        no already set
-        setup_distance_measure_getter: method to setup the distance
-        measures based upon the dataset given
-        get_gain: method to find the gain of a data split
-        :param max_depth: maximum depth of the tree
-        :param is_leaf: function to decide when to mark a node as a leaf node
-        :param verbosity: number reflecting the verbosity of logging
-        :param n_jobs: number of parallel threads to use while building
-        :param find_stump: method to find the best split of data / stump at
-        a node
-        :param n_stump_evaluations: number of stump evaluations to do if
-        find_stump method is None
-        :param n_estimators: number of trees to construct
-        """
         self.is_leaf = is_leaf
         self.verbosity = verbosity
         self.max_depth = max_depth
@@ -1369,6 +1322,7 @@ class ProximityForest(BaseClassifier):
         self.trees = None
         self.X = None
         self.y = None
+        self._random_object = None
 
         super(ProximityForest, self).__init__()
 
@@ -1423,15 +1377,9 @@ class ProximityForest(BaseClassifier):
         -------
         self : object
         """
-        X, y = check_X_y(X, y, enforce_univariate=True, coerce_to_pandas=True)
         self.X = _positive_dataframe_indices(X)
-        self.random_state = check_random_state(self.random_state)
-        # setup label encoding
-        if self.label_encoder is None:
-            self.label_encoder = LabelEncoder()
-            y = self.label_encoder.fit_transform(y)
+        self._random_object = check_random_state(self.random_state)
         self.y = y
-        self.classes_ = self.label_encoder.classes_
         if self.distance_measure is None:
             if self.get_distance_measure is None:
                 self.get_distance_measure = self.setup_distance_measure_getter(self)
@@ -1440,14 +1388,14 @@ class ProximityForest(BaseClassifier):
             parallel = Parallel(self._threads_to_use)
             self.trees = parallel(
                 delayed(self._fit_tree)(
-                    X, y, index, self.random_state.randint(0, self.n_estimators)
+                    X, y, index, self._random_object.randint(0, self.n_estimators)
                 )
                 for index in range(self.n_estimators)
             )
         else:
             self.trees = [
                 self._fit_tree(
-                    X, y, index, self.random_state.randint(0, self.n_estimators)
+                    X, y, index, self._random_object.randint(0, self.n_estimators)
                 )
                 for index in range(self.n_estimators)
             ]
@@ -1476,7 +1424,7 @@ class ProximityForest(BaseClassifier):
         """
         return tree.predict_proba(X)
 
-    def _predict(self, X):
+    def _predict(self, X) -> np.ndarray:
         """Predicts labels for sequences in X.
 
         Parameters
@@ -1500,11 +1448,10 @@ class ProximityForest(BaseClassifier):
             distribution = distributions[instance_index]
             prediction = np.argmax(distribution)
             predictions.append(prediction)
-        y = self.label_encoder.inverse_transform(predictions)
 
-        return y
+        return np.array(predictions)
 
-    def _predict_proba(self, X):
+    def _predict_proba(self, X) -> np.ndarray:
         """Find probability estimates for each class for all cases in X.
 
         Parameters
@@ -1535,6 +1482,33 @@ class ProximityForest(BaseClassifier):
         normalize(distributions, copy=False, norm="l1")
         return distributions
 
+    @classmethod
+    def get_test_params(cls, parameter_set="default"):
+        """Return testing parameter settings for the estimator.
+
+        Parameters
+        ----------
+        parameter_set : str, default="default"
+            Name of the set of test parameters to return, for use in tests. If no
+            special parameters are defined for a value, will return `"default"` set.
+            For classifiers, a "default" set of parameters should be provided for
+            general testing, and a "results_comparison" set for comparing against
+            previously recorded results if the general set does not produce suitable
+            probabilities to compare against.
+
+        Returns
+        -------
+        params : dict or list of dict, default={}
+            Parameters to create testing instances of the class.
+            Each dict are parameters to construct an "interesting" test instance, i.e.,
+            `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
+            `create_test_instance` uses the first (or only) dictionary in `params`.
+        """
+        if parameter_set == "results_comparison":
+            return {"n_estimators": 3, "max_depth": 2, "n_stump_evaluations": 2}
+        else:
+            return {"n_estimators": 2, "max_depth": 1, "n_stump_evaluations": 1}
+
 
 # start of util functions
 
@@ -1675,10 +1649,10 @@ def _stdp(X):
             for value in instance:
                 num_values += 1
                 sum += value
-                sum_sq += value ** 2  # todo missing values NaN messes
+                sum_sq += value**2  # todo missing values NaN messes
                 # this up!
     mean = sum / num_values
-    stdp = np.math.sqrt(sum_sq / num_values - mean ** 2)
+    stdp = np.math.sqrt(sum_sq / num_values - mean**2)
     return stdp
 
 
