@@ -9,13 +9,14 @@ from numpy.random import RandomState
 from sklearn.utils import check_random_state
 from sklearn.utils.extmath import stable_cumsum
 
-from sktime.clustering._base import BaseClusterer
-from sktime.clustering.metrics.averaging._averaging import mean_average
+from sktime.clustering.base import BaseClusterer
+from sktime.clustering.metrics.averaging import mean_average
 from sktime.distances import distance_factory, pairwise_distance
+from sktime.distances._ddtw import average_of_slope_transform
 
 
 def _forgy_center_initializer(
-    X: np.ndarray, n_clusters: int, random_state: np.random.RandomState
+    X: np.ndarray, n_clusters: int, random_state: np.random.RandomState, **kwargs
 ) -> np.ndarray:
     """Compute the initial centers using forgy method.
 
@@ -38,7 +39,7 @@ def _forgy_center_initializer(
 
 
 def _random_center_initializer(
-    X: np.ndarray, n_clusters: int, random_state: np.random.RandomState
+    X: np.ndarray, n_clusters: int, random_state: np.random.RandomState, **kwargs
 ) -> np.ndarray:
     """Compute initial centroids using random method.
 
@@ -60,12 +61,15 @@ def _random_center_initializer(
     np.ndarray (3d array of shape (n_clusters, n_dimensions, series_length))
         Indexes of the cluster centers.
     """
-    new_centers = np.zeros((n_clusters, X.shape[1], X.shape[2]))
+    new_centres = np.zeros((n_clusters, X.shape[1], X.shape[2]))
     selected = random_state.choice(n_clusters, X.shape[0], replace=True)
     for i in range(n_clusters):
         curr_indexes = np.where(selected == i)[0]
-        new_centers[i, :] = mean_average(X[curr_indexes])
-    return new_centers
+        result = mean_average(X[curr_indexes])
+        if result.shape[0] > 0:
+            new_centres[i, :] = result
+
+    return new_centres
 
 
 def _kmeans_plus_plus(
@@ -75,6 +79,7 @@ def _kmeans_plus_plus(
     distance_metric: str = "euclidean",
     n_local_trials: int = None,
     distance_params: dict = None,
+    **kwargs,
 ):
     """Compute initial centroids using kmeans++ method.
 
@@ -124,10 +129,7 @@ def _kmeans_plus_plus(
     center_id = random_state.randint(n_samples)
     centers[0] = X[center_id]
     closest_dist_sq = (
-        pairwise_distance(
-            centers[0, np.newaxis], X, metric=distance_metric, **distance_params
-        )
-        ** 2
+        pairwise_distance(centers[0, np.newaxis], X, metric=distance_metric) ** 2
     )
     current_pot = closest_dist_sq.sum()
 
@@ -137,10 +139,7 @@ def _kmeans_plus_plus(
         np.clip(candidate_ids, None, closest_dist_sq.size - 1, out=candidate_ids)
 
         distance_to_candidates = (
-            pairwise_distance(
-                X[candidate_ids], X, metric=distance_metric, **distance_params
-            )
-            ** 2
+            pairwise_distance(X[candidate_ids], X, metric=distance_metric) ** 2
         )
 
         np.minimum(closest_dist_sq, distance_to_candidates, out=distance_to_candidates)
@@ -226,7 +225,6 @@ class TimeSeriesLloyds(BaseClusterer, ABC):
         random_state: Union[int, RandomState] = None,
         distance_params: dict = None,
     ):
-        self.n_clusters = n_clusters
         self.init_algorithm = init_algorithm
         self.metric = metric
         self.n_init = n_init
@@ -242,8 +240,13 @@ class TimeSeriesLloyds(BaseClusterer, ABC):
         self.n_iter_ = 0
 
         self._random_state = None
+        self._init_algorithm = None
 
-        super(TimeSeriesLloyds, self).__init__()
+        self._distance_params = distance_params
+        if distance_params is None:
+            self._distance_params = {}
+
+        super(TimeSeriesLloyds, self).__init__(n_clusters=n_clusters)
 
     def _check_params(self, X: np.ndarray) -> None:
         """Check parameters are valid and initialized.
@@ -261,8 +264,6 @@ class TimeSeriesLloyds(BaseClusterer, ABC):
         """
         self._random_state = check_random_state(self.random_state)
 
-        self._distance_metric = distance_factory(X[0], X[1], metric=self.metric)
-
         if isinstance(self.init_algorithm, str):
             self._init_algorithm = self._init_algorithms.get(self.init_algorithm)
         else:
@@ -280,7 +281,11 @@ class TimeSeriesLloyds(BaseClusterer, ABC):
         else:
             self._distance_params = self.distance_params
 
-    def _fit(self, X: np.ndarray, y=None) -> np.ndarray:
+        self._distance_metric = distance_factory(
+            X[0], X[1], metric=self.metric, **self._distance_params
+        )
+
+    def _fit(self, X: np.ndarray, y=None):
         """Fit time series clusterer to training data.
 
         Parameters
@@ -296,7 +301,20 @@ class TimeSeriesLloyds(BaseClusterer, ABC):
             Fitted estimator.
         """
         self._check_params(X)
-
+        if self.metric == "ddtw" or self.metric == "wddtw":
+            X = average_of_slope_transform(X)
+            if self.metric == "ddtw":
+                self._distance_metric = distance_factory(
+                    X[0], X[1], metric="dtw", **self._distance_params
+                )
+            else:
+                self._distance_metric = distance_factory(
+                    X[0], X[1], metric="wdtw", **self._distance_params
+                )
+        else:
+            self._distance_metric = distance_factory(
+                X[0], X[1], metric=self.metric, **self._distance_params
+            )
         best_centers = None
         best_inertia = np.inf
         best_labels = None
@@ -313,6 +331,7 @@ class TimeSeriesLloyds(BaseClusterer, ABC):
         self.inertia_ = best_inertia
         self.cluster_centers_ = best_centers
         self.n_iter_ = best_iters
+        return self
 
     def _predict(self, X: np.ndarray, y=None) -> np.ndarray:
         """Predict the closest cluster each sample in X belongs to.
@@ -329,6 +348,8 @@ class TimeSeriesLloyds(BaseClusterer, ABC):
         np.ndarray (1d array of shape (n_instances,))
             Index of the cluster each time series in X belongs to.
         """
+        if self.metric == "ddtw" or self.metric == "wddtw":
+            X = average_of_slope_transform(X)
         return self._assign_clusters(X, self.cluster_centers_)[0]
 
     def _fit_one_init(self, X) -> Tuple[np.ndarray, np.ndarray, float, int]:
@@ -351,20 +372,24 @@ class TimeSeriesLloyds(BaseClusterer, ABC):
             Labels that is the index each time series belongs to.
         np.ndarray (3d array of shape (n_clusters, n_dimensions,
             series_length))
-            Time series that represent each of the cluster centers. If the algorithm
+            Time series that represent each of the cluster centres. If the algorithm
             stops before fully converging these will not be consistent with labels.
         float
             Sum of squared distances of samples to their closest cluster center,
             weighted by the sample weights if provided.
         """
-        cluster_centers = self._init_algorithm(X, self.n_clusters, self._random_state)
-
+        cluster_centres = self._init_algorithm(
+            X,
+            self.n_clusters,
+            self._random_state,
+            distance_metric=self._distance_metric,
+        )
         old_inertia = np.inf
         old_labels = None
         for i in range(self.max_iter):
             labels, inertia = self._assign_clusters(
                 X,
-                cluster_centers,
+                cluster_centres,
             )
 
             if np.abs(old_inertia - inertia) < self.tol:
@@ -380,7 +405,7 @@ class TimeSeriesLloyds(BaseClusterer, ABC):
             elif old_labels is not None:
                 # No strict convergence, check for tol based convergence.
                 center_shift = pairwise_distance(
-                    labels, old_labels, metric=self.metric, **self._distance_params
+                    labels, old_labels, metric=self._distance_metric
                 ).sum()
                 if center_shift <= self.tol:
                     if self.verbose:
@@ -391,18 +416,18 @@ class TimeSeriesLloyds(BaseClusterer, ABC):
                     break
             old_labels = labels
 
-            cluster_centers = self._compute_new_cluster_centers(X, labels)
+            cluster_centres = self._compute_new_cluster_centers(X, labels)
 
             if self.verbose is True:
                 print(f"Iteration {i}, inertia {inertia}.")  # noqa: T001
 
-        labels, inertia = self._assign_clusters(X, cluster_centers)
-        centers = cluster_centers
+        labels, inertia = self._assign_clusters(X, cluster_centres)
+        centres = cluster_centres
 
-        return labels, centers, inertia, i + 1
+        return labels, centres, inertia, i + 1
 
     def _assign_clusters(
-        self, X: np.ndarray, cluster_centers: np.ndarray
+        self, X: np.ndarray, cluster_centres: np.ndarray
     ) -> Tuple[np.ndarray, float]:
         """Assign each instance to a cluster.
 
@@ -414,7 +439,7 @@ class TimeSeriesLloyds(BaseClusterer, ABC):
         ----------
         X : np.ndarray (3d array of shape (n_instances, n_dimensions, series_length))
             Time series instances to predict their cluster indexes.
-        cluster_centers: np.ndarray (3d array of shape
+        cluster_centres: np.ndarray (3d array of shape
                                         (n_clusters, n_dimensions, series_length))
             Cluster centers to assign to.
 
@@ -427,10 +452,13 @@ class TimeSeriesLloyds(BaseClusterer, ABC):
             the assigned clusters.
         """
         pairwise = pairwise_distance(
-            X, cluster_centers, metric=self.metric, **self._distance_params
+            X, cluster_centres, metric=self.metric, **self._distance_params
         )
         return pairwise.argmin(axis=1), pairwise.min(axis=1).sum()
 
+    def _score(self, X, y=None):
+        return -self.inertia_
+
     @abstractmethod
     def _compute_new_cluster_centers(
         self, X: np.ndarray, assignment_indexes: np.ndarray
