@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+__author__ = ["chrisholder", "TonyBagnall"]
+
 from typing import Callable
 
 import numpy as np
@@ -8,22 +10,40 @@ from sktime.distances.base import DistanceCallable
 
 
 @njit(cache=True)
-def _check_numba_pairwise_series(x: np.ndarray) -> np.ndarray:
-    """Check a potential series being passed into pairwise.
+def _make_3d_series(x: np.ndarray) -> np.ndarray:
+    """Check a series being passed into pairwise is 3d.
+
+    Pairwise assumes it has been passed two sets of series, if passed a single
+    series this function reshapes.
+
+    If given a 1d array the time series is reshaped to (m, 1, 1). This is so when
+    looped over x[i] = (1, m).
+
+    If given a 2d array then the time series is reshaped to (d, 1, m). The dimensions
+    are put to the start so the ts can be looped through correctly. When looped over
+    the time series x[i] = (d, m).
 
     Parameters
     ----------
-    x: np.ndarray
-        A timeseries
+    x: np.ndarray, 2d or 3d
 
     Returns
     -------
-    np.ndarray
-        Validated and reshaped (where appropriate) timeseries.
+    np.ndarray, 3d
     """
-    if x.ndim == 2:
+    num_dims = x.ndim
+    if num_dims == 1:
         shape = x.shape
-        _x = np.reshape(x, (shape[0], shape[1], 1))
+        _x = np.reshape(x, (shape[0], 1, 1))
+    elif num_dims == 2:
+        shape = x.shape
+        _x = np.reshape(x, (shape[0], 1, shape[1]))
+    elif num_dims > 3:
+        raise ValueError(
+            "The matrix provided has more than 3 dimensions. This is not"
+            "supported. Please provide a matrix with less than "
+            "3 dimensions"
+        )
     else:
         _x = x
     return _x
@@ -37,12 +57,12 @@ def _compute_pairwise_distance(
     Parameters
     ----------
     x: np.ndarray (2d or 3d array)
-        First timeseries.
+        First time series.
     y: np.ndarray (2d or 3d array)
-        Second timeseries.
+        Second time series.
     symmetric: bool
-        Boolean that is true when x == y and false when x != y. Used in some instances
-        to speed up pairwise computation.
+        Boolean that is true when distance_callable(x,y) == distance_callable(y,x).
+        Used in some to speed up pairwise computation for symmetric distance functions.
     distance_callable: Callable[[np.ndarray, np.ndarray], float]
         No_python distance callable to measure the distance between two 2d numpy
         arrays.
@@ -50,11 +70,10 @@ def _compute_pairwise_distance(
     Returns
     -------
     np.ndarray (2d of size mxn where m is len(x) and n is len(y)).
-        Pairwise distance matrix between the two timeseries.
+        Pairwise distance matrix between the two time series.
     """
-    _x = _check_numba_pairwise_series(x)
-    _y = _check_numba_pairwise_series(y)
-
+    _x = _make_3d_series(x)
+    _y = _make_3d_series(y)
     x_size = _x.shape[0]
     y_size = _y.shape[0]
 
@@ -67,7 +86,6 @@ def _compute_pairwise_distance(
                 pairwise_matrix[i, j] = pairwise_matrix[j, i]
             else:
                 pairwise_matrix[i, j] = distance_callable(curr_x, _y[j])
-
     return pairwise_matrix
 
 
@@ -107,63 +125,18 @@ def is_no_python_compiled_callable(
     return is_no_python_callable
 
 
-def to_numba_pairwise_timeseries(x: np.ndarray) -> np.ndarray:
-    """Convert a timeseries to a valid timeseries for numba pairwise use.
-
-    Parameters
-    ----------
-    x: np.ndarray (1d, 2d or 3d array)
-        A timeseries.
-
-    Returns
-    -------
-    np.ndarray (3d array)
-        3d array that is the formatted pairwise timeseries.
-
-    Raises
-    ------
-    ValueError
-        If the value provided is not a numpy array
-        If the matrix provided is greater than 3 dimensions
-    """
-    if not isinstance(x, np.ndarray):
-        raise ValueError(
-            f"The value {x} is an invalid timeseries. To perform a "
-            f"distance computation a numpy arrays must be provided."
-        )
-
-    _x = np.array(x, copy=True, dtype=np.float)
-    num_dims = _x.ndim
-    if num_dims == 1:
-        shape = _x.shape
-        _x = np.reshape(_x, (1, 1, shape[0]))
-    elif num_dims == 2:
-        shape = _x.shape
-        _x = np.reshape(_x, (shape[0], shape[1], 1))
-    elif num_dims == 3:
-        shape = _x.shape
-        _x = np.reshape(_x, (shape[0], shape[1], shape[2]))
-    elif num_dims > 3:
-        raise ValueError(
-            "The matrix provided has more than 3 dimensions. This is not"
-            "supported. Please provide a matrix with less than "
-            "3 dimensions"
-        )
-    return _x
-
-
 def to_numba_timeseries(x: np.ndarray) -> np.ndarray:
-    """Convert a timeseries to a valid timeseries for numba use.
+    """Convert a time series to a valid time series for numba use.
 
     Parameters
     ----------
     x: np.ndarray (1d or 2d)
-        A timeseries.
+        A time series.
 
     Returns
     -------
     np.ndarray (2d array)
-        2d array that is the formatted timeseries.
+        2d array that is the formatted time series.
 
     Raises
     ------
@@ -177,14 +150,27 @@ def to_numba_timeseries(x: np.ndarray) -> np.ndarray:
             f"distance computation a numpy array must be provided."
         )
 
-    _x = np.array(x, copy=True, dtype=np.float)
+    _x = np.array(x, copy=True, dtype=float)
     num_dims = _x.ndim
     shape = _x.shape
+    if num_dims == 1 or (num_dims == 2 and _x.shape[1] == 1 and _x.shape[0] != 1):
+        _x = np.reshape(_x, (1, shape[0]))
+    elif num_dims > 2:
+        raise ValueError(
+            "The matrix provided has more than 2 dimensions. This is not"
+            "supported. Please provide a matrix with less than "
+            "2 dimensions"
+        )
+    return _x
+
+
+@njit(cache=True)
+def _numba_to_timeseries(x: np.ndarray) -> np.ndarray:
+    _x = x.copy()
+    num_dims = _x.ndim
+    shape = _x.shape
     if num_dims == 1:
-        _x = np.reshape(_x, (shape[0], 1))
-    if num_dims == 2 and shape[0] == 1:
-        _x = np.reshape(_x, (shape[1], shape[0]))
-
+        _x = np.reshape(_x, (1, shape[0]))
     elif num_dims > 2:
         raise ValueError(
             "The matrix provided has more than 2 dimensions. This is not"
