@@ -631,6 +631,7 @@ class _DirRecReducer(_Reducer):
     strategy = "dirrec"
     _tags = {
         "requires-fh-in-fit": True,  # is the forecasting horizon required in fit?
+        "ignores-exogeneous-X": True,
     }
 
     def _transform(self, y, X=None):
@@ -662,12 +663,9 @@ class _DirRecReducer(_Reducer):
         self : Estimator
             An fitted instance of self.
         """
-        # Exogenous variables are not yet supported for the dirrec strategy.
+        # todo: logic for X below is broken. Escape X until fixed.
         if X is not None:
-            raise NotImplementedError(
-                f"{self.__class__.__name__} does not yet support exogenous "
-                f"variables `X`."
-            )
+            X = None
 
         if len(self.fh.to_in_sample(self.cutoff)) > 0:
             raise NotImplementedError("In-sample predictions are not implemented")
@@ -704,19 +702,15 @@ class _DirRecReducer(_Reducer):
 
             estimator.fit(X_fit, yt[:, i])
             self.estimators_.append(estimator)
-
-        self._is_fitted = True
         return self
 
     def _predict_last_window(
         self, fh, X=None, return_pred_int=False, alpha=DEFAULT_ALPHA
     ):
         # Exogenous variables are not yet support for the dirrec strategy.
+        # todo: implement this. For now, we escape.
         if X is not None:
-            raise NotImplementedError(
-                f"{self.__class__.__name__} does not yet support exogenous "
-                f"variables `X`."
-            )
+            X = None
 
         # Get last window of available data.
         y_last, X_last = self._get_last_window()
