@@ -11,7 +11,7 @@ from sktime.forecasting.base._base import DEFAULT_ALPHA
 from sktime.forecasting.base.adapters import _ProphetAdapter
 from sktime.utils.validation._dependencies import _check_soft_dependencies
 
-_check_soft_dependencies("prophet")
+_check_soft_dependencies("prophet", severity="warning")
 
 
 class Prophet(_ProphetAdapter):
@@ -19,7 +19,9 @@ class Prophet(_ProphetAdapter):
 
     Parameters
     ----------
-    freq: String of DatetimeIndex frequency. Refer [2]_ for possible values:
+    freq: str, default=None
+        A DatetimeIndex frequency. For possible values see
+        https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html
     add_seasonality: dict or None, default=None
         Dict with args for Prophet.add_seasonality().
         Dict can have the following keys/values:
@@ -99,7 +101,6 @@ class Prophet(_ProphetAdapter):
     References
     ----------
     .. [1] https://facebook.github.io/prophet
-    .. [2] https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html
 
     Examples
     --------
@@ -143,6 +144,8 @@ class Prophet(_ProphetAdapter):
         verbose=0,
         interval_width=0,
     ):
+        _check_soft_dependencies("prophet", severity="error", object=self)
+
         self.freq = freq
         self.add_seasonality = add_seasonality
         self.add_country_holidays = add_country_holidays
@@ -195,9 +198,16 @@ class Prophet(_ProphetAdapter):
         return self
 
     @classmethod
-    def get_test_params(cls):
+    def get_test_params(cls, parameter_set="default"):
         """Return testing parameter settings for the estimator.
 
+        Parameters
+        ----------
+        parameter_set : str, default="default"
+            Name of the set of test parameters to return, for use in tests. If no
+            special parameters are defined for a value, will return `"default"` set.
+
+
         Returns
         -------
         params : dict or list of dict
@@ -207,7 +217,7 @@ class Prophet(_ProphetAdapter):
             "yearly_seasonality": False,
             "weekly_seasonality": False,
             "daily_seasonality": False,
-            "uncertainty_samples": 1000,
+            "uncertainty_samples": 10,
             "verbose": False,
         }
         return params
