@@ -6,7 +6,7 @@ copyright: sktime developers, BSD-3-Clause License (see LICENSE file)
 
 __author__ = ["mloning", "fkiraly"]
 
-from inspect import signature
+from inspect import isclass, signature
 
 import numpy as np
 import pandas as pd
@@ -145,6 +145,8 @@ def _make_fit_args(estimator, **kwargs):
         return (X,)
     elif isinstance(estimator, (_PanelToTabularTransformer, _PanelToPanelTransformer)):
         return make_classification_problem(**kwargs)
+    elif isinstance(estimator, BaseTransformer) and estimator.get_tag("requires_y"):
+        return make_classification_problem(**kwargs)
     elif isinstance(estimator, BaseTransformer):
         X = _make_series(**kwargs)
         return (X,)
@@ -329,18 +331,31 @@ def _get_args(function, varargs=False):
 
 def _has_capability(est, method: str) -> bool:
     """Check whether estimator has capability of method."""
+
+    def get_tag(est, tag_name, tag_value_default=None):
+        if isclass(est):
+            return est.get_class_tag(
+                tag_name=tag_name, tag_value_default=tag_value_default
+            )
+        else:
+            return est.get_tag(tag_name=tag_name, tag_value_default=tag_value_default)
+
     if not hasattr(est, method):
         return False
     if method == "inverse_transform":
-        return est.get_class_tag("capability:inverse_transform", False)
+        return get_tag(est, "capability:inverse_transform", False)
     if method in [
         "predict_proba",
         "predict_interval",
         "predict_quantiles",
         "predict_var",
     ]:
-        # all classifiers implement predict_proba
-        if method == "predict_proba" and isinstance(est, BaseClassifier):
+        ALWAYS_HAVE_PREDICT_PROBA = (BaseClassifier, BaseClusterer)
+        # all classifiers and clusterers implement predict_proba
+        if method == "predict_proba" and isinstance(est, ALWAYS_HAVE_PREDICT_PROBA):
             return True
-        return est.get_class_tag("capability:pred_int", False)
+        return get_tag(est, "capability:pred_int", False)
+    # skip transform for forecasters that have it - pipelines
+    if method == "transform" and isinstance(est, BaseForecaster):
+        return False
     return True
